@@ -259,6 +259,15 @@ class ClickHouseGenerator(Generator, DatabaseMixin):
     source = "clickhouse"
 
 
-# TODO	Add Kafka support
-#	Add inputs to kuberflow
+class DVCGenerator(Generator):
+    source = "dvc"
+
+    def get_stage(self, name: str) -> str:
+        data = OrderedDict({"stages": name})
+        return self.get_oddrn(data)
+
+    def get_dataset(self, file_path: str) -> str:
+        folders = [f"folder/{path}" for path in file_path.split("/")]
+        oddrn = "/".join(folders)
+        return f"{self._base_oddrn}/{oddrn}"
 
